# In_container

*In_container* allows you to check if you are running your program inside a Docker container.

Like this:
```python
from in_container import in_container
print(in_container()) # True or False
```